==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/acpacl.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'acl_seg_acp_acl_delete'=>'Zugriffsregel: Regel löschen',
'acl_seg_acp_acl_edit'=>'Zugriffsregel: Regel ändern',
'acl_seg_acp_acl_list'=>'Zugriffsregel: Regeln auflisten',
'acl_seg_acp_acl_new'=>'Zugriffsregel: Regel hinzufügen',
'acl_seg_acp_cfg_edit'=>'Einstellungen: Bearbeiten',
'acl_seg_acp_cfg_list'=>'Einstellungen: Auflisten',
'acl_seg_acp_group_delete'=>'Benutzergruppe: Gruppe löschen',
'acl_seg_acp_group_edit'=>'Benutzergruppe: Gruppe ändern',
'acl_seg_acp_group_list'=>'Benutzergruppe: Gruppen auflisten',
'acl_seg_acp_group_new'=>'Benutzergruppe: Gruppe hinzufügen',
'acl_seg_acp_log'=>'Protokoll anschauen',
'acl_seg_acp_overview'=>'Verwalter-Konsole',
'acl_seg_acp_pp_delete'=>'Beitragpräfix: Präfix löschen',
'acl_seg_acp_pp_edit'=>'Beitragpräfix: Präfix ändern',
'acl_seg_acp_pp_list'=>'Beitragpräfix: Präfixe auflisten',
'acl_seg_acp_pp_new'=>'Beitragpräfix: Präfix hinzufügen',
'acl_seg_acp_task_edit'=>'Geplante Aufgabe: Aufgabe ändern',
'acl_seg_acp_task_list'=>'Geplante Aufgabe: Aufgaben auflisten',
'acl_seg_acp_user_new'=>'Benutzerkonto: Benutzer hinzufügen',
'acl_seg_cachemgr'=>'Zwischenspeicher-Verwaltung',
'acl_seg_forgot_password'=>'Kennwort vergessen',
'acl_seg_help'=>'Hilfe',
'acl_seg_login'=>'Anmeldung',
'acl_seg_logout'=>'Abmeldung',
'acl_seg_mcp_overview'=>'Moderation-Konsole',
'acl_seg_mcp_request'=>'Moderation: Anfragen bearbeiten',
'acl_seg_member_list'=>'Mitgliederliste',
'acl_seg_overview'=>'Startseite',
'acl_seg_post_approve'=>'Beitrag freischalten/verstecken',
'acl_seg_post_delete'=>'Beitrag löschen',
'acl_seg_post_edit'=>'Beitrag ändern',
'acl_seg_post_edit_revert'=>'Beitrag rücksetzen',
'acl_seg_post_lock'=>'Beitrag schließen/öffnen',
'acl_seg_post_rate'=>'Beitrag bewerten',
'acl_seg_post_reply'=>'Eine Antwort schreiben',
'acl_seg_post_topic'=>'Ein Thema schreiben',
'acl_seg_reauth'=>'Anmeldung erneuern',
'acl_seg_register'=>'Registrieren',
'acl_seg_rss'=>'RSS-Feed',
'acl_seg_search'=>'Suche',
'acl_seg_topic'=>'Themen-Ansicht',
'acl_seg_ucp_blacklist'=>'Benutzerkonsole: Schwarze Liste',
'acl_seg_ucp_bookmark'=>'Benutzerkonsole: Lesezeichen',
'acl_seg_ucp_profile'=>'Benutzerkonsole: Mein Profil',
'acl_seg_ucp_request'=>'Benutzerkonsole: Anfragen bearbeiten'
);
?>

==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/lang/de/acpacl.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'acl_seg_acp_acl_delete'=>'Zugriffsregel: Regel löschen',
'acl_seg_acp_acl_edit'=>'Zugriffsregel: Regel ändern',
'acl_seg_acp_acl_list'=>'Zugriffsregel: Regeln auflisten',
'acl_seg_acp_acl_new'=>'Zugriffsregel: Regel hinzufügen',
'acl_seg_acp_announcement'=>'Globale Ankündigung',
'acl_seg_acp_cfg_edit'=>'Einstellungen: Bearbeiten',
'acl_seg_acp_cfg_list'=>'Einstellungen: Auflisten',
'acl_seg_acp_group_delete'=>'Benutzergruppe: Gruppe löschen',
'acl_seg_acp_group_edit'=>'Benutzergruppe: Gruppe ändern',
'acl_seg_acp_group_list'=>'Benutzergruppe: Gruppen auflisten',
'acl_seg_acp_group_new'=>'Benutzergruppe: Gruppe hinzufügen',
'acl_seg_acp_log'=>'Protokoll anschauen',
'acl_seg_acp_overview'=>'Verwalter-Konsole',
'acl_seg_acp_pp_delete'=>'Beitragpräfix: Präfix löschen',
'acl_seg_acp_pp_edit'=>'Beitragpräfix: Präfix ändern',
'acl_seg_acp_pp_list'=>'Beitragpräfix: Präfixe auflisten',
'acl_seg_acp_pp_new'=>'Beitragpräfix: Präfix hinzufügen',
'acl_seg_acp_task_edit'=>'Geplante Aufgabe: Aufgabe ändern',
'acl_seg_acp_task_list'=>'Geplante Aufgabe: Aufgaben auflisten',
'acl_seg_acp_user_delete'=>'Benutzerkonto: Benutzer löschen',
'acl_seg_acp_user_new'=>'Benutzerkonto: Benutzer hinzufügen',
'acl_seg_cachemgr'=>'Zwischenspeicher-Verwaltung',
'acl_seg_forgot_password'=>'Kennwort vergessen',
'acl_seg_help'=>'Hilfe',
'acl_seg_login'=>'Anmeldung',
'acl_seg_logout'=>'Abmeldung',
'acl_seg_mcp_overview'=>'Moderation-Konsole',
'acl_seg_mcp_request'=>'Moderation: Anfragen bearbeiten',
'acl_seg_member_list'=>'Mitgliederliste',
'acl_seg_overview'=>'Startseite',
'acl_seg_post_approve'=>'Beitrag freischalten/verstecken',
'acl_seg_post_delete'=>'Beitrag löschen',
'acl_seg_post_edit'=>'Beitrag ändern',
'acl_seg_post_edit_revert'=>'Beitrag rücksetzen',
'acl_seg_post_lock'=>'Beitrag schließen/öffnen',
'acl_seg_post_rate'=>'Beitrag bewerten',
'acl_seg_post_reply'=>'Eine Antwort schreiben',
'acl_seg_post_topic'=>'Ein Thema schreiben',
'acl_seg_reauth'=>'Anmeldung erneuern',
'acl_seg_register'=>'Registrieren',
'acl_seg_rss'=>'RSS-Feed',
'acl_seg_search'=>'Suche',
'acl_seg_topic'=>'Themen-Ansicht',
'acl_seg_ucp_blacklist'=>'Benutzerkonsole: Schwarze Liste',
'acl_seg_ucp_bookmark'=>'Benutzerkonsole: Lesezeichen',
'acl_seg_ucp_profile'=>'Benutzerkonsole: Mein Profil',
'acl_seg_ucp_request'=>'Benutzerkonsole: Anfragen bearbeiten',
'acl_seg_vcard'=>'Visitenkarte'
);
?>
